@@ -40,7 +40,7 @@
 #include "../i387/osx_asm.h"
 #define CNAME(x) EXT(x)
 #else
-#include "bsd_cdefs.h"
+#include "cdefs-compat.h"
 
 #ifdef PIC
 #define	PIC_PLT(x)	x@PLT
@@ -76,7 +76,7 @@
 #define _START_ENTRY_WIN .code; _START_ENTRY
 #endif
 #define _ENTRY(x)	_START_ENTRY_WIN; \
-            .globl CNAME(x); .section .drectve; .ascii " -export:" #x; \
+            .globl CNAME(x); .section .drectve; .ascii " -export:", #x; \
             .section .text; .def CNAME(x); .scl 2; .type 32; .endef; CNAME(x):
 #endif
 
